@@ -1,28 +1,30 @@
 import asyncio
 import aiosqlite
+
 from typing import Iterable, Any
 
 
 class Synchronizer:
     def __init__(self):
-        self.is_open = True
-
-    def open(self) -> None:
-        self.is_open = True
-
-    def close(self) -> None:
-        self.is_open = False
+        self.queue = []
 
     async def __aenter__(self):
+        event = asyncio.Event()
+        self.queue.append(event)
         await self.wait_for_opening()
-        self.close()
 
     async def __aexit__(self, *args, **kwargs):
-        self.open()
+        if len(self.queue) > 1:
+            event = self.queue.pop(1)
+            event.set()
+        else:
+            self.queue.pop(0)
 
     async def wait_for_opening(self) -> None:
-        while not self.is_open:
-            await asyncio.sleep(0.2)
+        if len(self.queue) < 2:
+            return
+
+        await self.queue[-1].wait()
 
 
 class SQLite(Synchronizer):
