@@ -15,8 +15,8 @@ class Handler:
         self.func = func
 
     def __call__(self, func):
-        async def wrapper(token: str, event: dict, event_params: dict, chain_data: Any):
-            return await func(get_dispatcher_by_event(token, event, event_params, chain_data))
+        async def wrapper(bot, event: dict, event_params: dict, chain_data: Any):
+            return await func(get_dispatcher_by_event(bot, event, event_params, chain_data))
 
         return type(self)(self.condition, self.is_lower, wrapper)
 
@@ -27,12 +27,16 @@ class Handler:
         if self.is_lower:
             if event_params["text"]:
                 event_params["text"] = event_params["text"].lower()
+            if "text" in event_params["action"]:
+                event_params["action"]["text"] = event_params["action"]["text"].lower()
+            if "text" in event_params["reply"]:
+                event_params["reply"]["text"] = event_params["reply"]["text"].lower()
 
         return self.condition is None or self.condition.new_event(event_params)
 
-    async def new_event(self, token: str, event: dict, event_params: dict, chain_data: Any = None) -> Any:
+    async def new_event(self, bot, event: dict, event_params: dict, chain_data: Any = None) -> Any:
         try:
-            return await self.func(token, event, event_params, chain_data)
+            return await self.func(bot, event, event_params, chain_data)
         except:
             sys.stderr.write(f"\n\n{traceback.format_exc()}\n\n")
 
